# -*- coding: latin-1 -*-

"""
SimpleGUICS2Pygame package (December 16, 2013)

It is primarily a standard Python_ (2 **and** 3) module
reimplementing the SimpleGUI particular module of CodeSkulptor_
(a browser Python interpreter).

Require Pygame_
(except for the Timer class)
(`Unofficial Windows Binaries`_)
(and must be installed separately).

Module simpleplot require matplotlib_ .


`Online HTML documentation`_ on Read The Docs.

Piece of SimpleGUICS2Pygame.
https://bitbucket.org/OPiMedia/simpleguics2pygame

GPLv3 --- Copyright (C) 2013 Olivier Pirson
http://www.opimedia.be/

.. _CodeSkulptor: http://www.codeskulptor.org/
.. _`Online HTML documentation`: https://readthedocs.org/docs/simpleguics2pygame/en/latest/
.. _Pygame: http://www.pygame.org/
.. _Python: http://www.python.org/
.. _`Unofficial Windows Binaries`: http://www.lfd.uci.edu/~gohlke/pythonlibs/#pygame

v.01.04.00 --- December 16, 2013
v.01.03.00 --- December 13, 2013
v.01.02.00 --- November 8, 2013
v.01.01.00 --- November 1st, 2013
v.01.00.02 --- October 31, 2013
v.01.00.01 --- October 9, 2013
v.01.00.00 --- July 13, 2013
v.00.92.00 --- June 27, 2013
v.00.91.00 --- June 23, 2013
v.00.90.10 --- June 19, 2013
v.00.90.00 --- June 13, 2013
Started on May 21, 2013

`Complete changelog`_

.. _`Complete changelog`: https://simpleguics2pygame.readthedocs.org/en/latest/ChangeLog.html
"""

_VERSION = '01.04.00'
"""
Version of SimpleGUICS2Pygame package.
"""

_WEBSITE = 'https://bitbucket.org/OPiMedia/simpleguics2pygame'
"""
Website of the project.
"""


#
# GPLv3
# ------
# Copyright (C) 2013 Olivier Pirson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
